var AdvPopup;

AdvPopup = AdvPopup || {};

AdvPopup.Layers = Backbone.Collection.extend({
	model: function(attrs, options) {
		var LayerClass;
		LayerClass = AdvPopup.app.getRegisteredLayerClassByType(attrs['type']);
		if (!LayerClass) {
			console.error('Cannot detect layer type', attrs, options);
			return new AdvPopup.Layer(attrs, options);
		}
		return new LayerClass(attrs, options);
	}
});

AdvPopup = AdvPopup || {};

AdvPopup.Common = {
	siteUrl: '',
	getAbsUrl: function(url) {
		var regex;
		regex = /(http|https):\/\/(\w+:{0,1}\w*)?(\S+)(:[0-9]+)?(\/|\/([\w#!:.?+=&%!\-\/]))?/;
		if (regex.test(url)) {
			return url;
		} else {
			return AdvPopup.Common.siteUrl + url;
		}
	}
};

AdvPopup = AdvPopup || {};

jQuery(document).ready(function($) {
	new AdvPopup.AppView;
});

AdvPopup = AdvPopup || {};

AdvPopup.Model = Backbone.Model.extend({
	currentView: null,
	selected: false,
	defaultInitialize: function() {
		this.on('change', function() {
			Backbone.Events.trigger('advpopup:change', AdvPopup.app);
		});
	},
	setSelected: function() {
		AdvPopup.app.setSelected(this);
	},
	getCaption: function() {
		return '';
	}
});

AdvPopup = AdvPopup || {};

AdvPopup.Layer = AdvPopup.Model.extend({
	defaults: {
		type: '',
		left: 20,
		top: 20,
		width: 50,
		height: 50,
		angle: 0
	},
	sizeChangable: true,
	angleChangable: true,
	isNewLayer: true,
	initialize: function() {
		this.defaultInitialize();
	},
	toDegrees: function(angle) {
		angle = typeof angle === 'undefined' ? this.angle : angle * 180 / Math.PI;
		if (angle === Math.ceil(angle)) {
			return angle;
		} else {
			return angle.toFixed(2);
		}
	},
	toRadians: function(angle) {
		if (angle == null) {
			angle = this.get('angle');
		}
		return angle * Math.PI / 180;
	}
});

AdvPopup = AdvPopup || {};

AdvPopup.Overlay = AdvPopup.Model.extend({
	defaults: {
		image: '',
		repeat: '',
		position: '',
		attachment: '',
		color: '#000',
		opacity: '0.7'
	},
	initialize: function() {
		this.view = new AdvPopup.OverlayView({
			model: this
		});
		this.optionsView = new AdvPopup.OverlayOptionsView({
			model: this
		});
		this.defaultInitialize();
	},
	getCaption: function() {
		return '<i class="fa fa-television"></i> Overlay';
	}
});

AdvPopup = AdvPopup || {};

AdvPopup.Popup = AdvPopup.Model.extend({
	defaults: {
		color: '#e5e5e5',
		width: 500,
		height: 400,
		audio: ''
	},
	initialize: function() {
		this.view = new AdvPopup.PopupView({
			model: this
		});
		this.optionsView = new AdvPopup.PopupOptionsView({
			model: this
		});
		this.defaultInitialize();
	},
	getCaption: function() {
		return '<i class="fa fa-object-group"></i> Popup';
	}
});

AdvPopup = AdvPopup || {};

AdvPopup.AppView = Backbone.View.extend({
	el: '#advpopup-app-wrapper',
	isBackend: true,
	events: {
		'click .btn-remove-layer': 'removeSelectedLayer',
		'click .btn-remove-layers': 'removeAllLayers'
	},
	registeredLayersClasses: {},
	getLayerClassType: function(LayerClass) {
		if (typeof LayerClass.prototype.defaults === 'function') {
			return LayerClass.prototype.defaults().type;
		} else {
			return LayerClass.prototype.defaults.type;
		}
	},
	getRegisteredLayerClassByType: function(type) {
		return this.registeredLayersClasses[type];
	},
	registerLayerClass: function(LayerClass) {
		var type;
		if (!(LayerClass.prototype instanceof AdvPopup.Layer)) {
			console.error('Tried to register layer class that does not extend AdvPopup.Layer', LayerClass);
			return false;
		}
		type = this.getLayerClassType(LayerClass);
		if (typeof type !== 'string') {
			console.error('Invalid layer type: ' + type, LayerClass);
			return false;
		}
		if (typeof this.registeredLayersClasses[type] !== 'undefined') {
			console.error('Layer type "' + type + '" already registered', LayerClass);
			return false;
		}
		this.registeredLayersClasses[type] = LayerClass;
		return true;
	},
	changeSelected: function(model, selectedModel) {
		if (model === selectedModel && !model.selected) {
			model.selected = true;
			model.trigger('selected:change', model);
		} else if (model !== selectedModel && model.selected) {
			model.selected = false;
			model.trigger('selected:change', model);
		}
	},
	setSelected: function(model) {
		var that;
		that = this;
		_.each([this.overlay, this.popup], function(m) {
			that.changeSelected(m, model);
		});
		this.layers.each(function(layer) {
			that.changeSelected(layer, model);
		});
	},
	findModelByCid: function(cid) {
		var result, that;
		that = this;
		result = false;
		_.each([this.overlay, this.popup], function(model) {
			if (model.cid === cid) {
				result = model;
				return true;
			}
		});
		this.layers.each(function(model) {
			if (model.cid === cid) {
				result = model;
				return true;
			}
		});
		return result;
	},
	initialize: function() {
		var app, data, e, error;
		app = AdvPopup.app = this;
		this.$layersToolbar = this.$('.advp-layers-toolbar');
		this.$screenWrapper = this.$('.advp-screen-wrapper');
		this.$overlayWrapper = this.$('.advp-overlay-wrapper');
		this.$popupWrapper = this.$('.advp-popup-wrapper');
		this.$input = this.$('.advp-input');
		this.$optionsWrapper = this.$('.advp-options-wrapper');
		this.$orderingWrapper = this.$('.advp-ordering-wrapper');
		this.$removeLayer = this.$('.btn-remove-layer');
		this.overlay = new AdvPopup.Overlay;
		this.popup = new AdvPopup.Popup;
		this.layers = new AdvPopup.Layers;
		this.orderingView = new AdvPopup.OrderingView({
			model: {
				overlay: this.overlay,
				popup: this.popup,
				layers: this.layers
			}
		});
		Backbone.Events.trigger('layer:register', this);
		this.listenTo(this.layers, 'add change remove reset', this.layersChange);
		Backbone.Events.on('advpopup:change', function(app) {
			app.$input.val(JSON.stringify({
				overlay: app.overlay,
				popup: app.popup,
				layers: app.layers
			}));
		});
		try {
			data = JSON.parse(this.$input.val() || '{}');
		} catch (error) {
			e = error;
			console.error('Failed to recover popup data from input', e);
		}
		if (data.overlay) {
			this.overlay.set(data.overlay);
		}
		if (data.popup) {
			this.popup.set(data.popup);
		}
		if (data.layers) {
			this.layers.reset(data.layers);
		}
		this.$('.btn-layer-type').click(function(event) {
			var LayerClass, layer, type;
			event.stopPropagation();
			event.preventDefault();
			if (type = jQuery(this).data('layer-type')) {
				if (LayerClass = app.getRegisteredLayerClassByType(type)) {
					layer = new LayerClass;
					app.layers.add(layer);
					return app.setSelected(layer);
				} else {
					return console.warn('Unregistered layer type: ' + type);
				}
			} else {
				return console.warn('Cannot extract item type from button', type);
			}
		});
		this.$('.advp-btn-fullscreen').click(function(event) {
			var $adjustmentWrapper, $builderWrapper;
			event.stopPropagation();
			event.preventDefault();
			$builderWrapper = jQuery('.advp-builder-wrapper');
			$adjustmentWrapper = jQuery('.advp-adjustment-wrapper');
			if ($builderWrapper.hasClass('span7')) {
				$builderWrapper.removeClass('span7');
				$adjustmentWrapper.removeClass('span5');
				app.$optionsWrapper.addClass('span8');
				return app.$orderingWrapper.addClass('span4');
			} else {
				$builderWrapper.addClass('span7');
				$adjustmentWrapper.addClass('span5');
				app.$optionsWrapper.removeClass('span8');
				return app.$orderingWrapper.removeClass('span4');
			}
		});
	},
	render: function() {
		var that;
		that = this;
		this.layers.each(function(layer) {
			return that.$popupWrapper.append(layer.view.$el);
		});
		return this;
	},
	layersChange: function() {
		Backbone.Events.trigger('advpopup:change', this);
		this.render();
	},
	removeSelectedLayer: function(event) {
		event.stopPropagation();
		event.preventDefault();
		this.layers.each(function(layer) {
			if (layer.selected) {
				layer.destroy();
			}
		});
	},
	removeAllLayers: function(event) {
		event.stopPropagation();
		event.preventDefault();
		this.layers.reset();
		this.$popupWrapper.html('');
	}
});

AdvPopup = AdvPopup || {};

AdvPopup.View = Backbone.View.extend({
	initialize: function() {
		this.listenTo(this.model, 'change', this.beforeRender);
		this.listenTo(this.model, 'selected:change', this.render);
		this.listenTo(this.model, 'destroy', this.remove);
		this.defaultInitialize();
		this.render();
	},
	defaultInitialize: function() {},
	beforeRender: function(model, options) {
		if (this.model.currentView !== this) {
			this.render(model, options);
		} else {
			this.model.currentView = null;
		}
	},
	modelSet: function(key, val, options) {
		this.model.currentView = this;
		this.model.set(key, val, options);
	},
	selectOnClick: function(event) {
		if (jQuery(event.target).is(this.$el)) {
			this.model.setSelected();
		}
	}
});

AdvPopup = AdvPopup || {};

AdvPopup.LayerView = AdvPopup.View.extend({
	tagName: 'div',
	className: 'advp-layer',
	$inner: null,
	events: {
		'keyup': 'removeOnDelete',
		'click': 'selectOnClick'
	},
	initialize: function() {
		this.defaultInitialize();
		this.render();
	},
	defaultInitialize: function() {
		var that;
		this.$inner = jQuery('<div class="advp-layer-inner"></div>').appendTo(this.$el);
		this.listenTo(this.model, 'change', this.beforeRender);
		this.listenTo(this.model, 'selected:change', this.render);
		this.listenTo(this.model, 'destroy', this.remove);
		that = this;
		this.$el.draggable({
			drag: function(event, ui) {
				that.modelSet({
					left: ui.position.left,
					top: ui.position.top
				});
			},
			stop: function(event, ui) {
				that.model.set({
					left: ui.position.left,
					top: ui.position.top
				});
				that.$el.focus();
				that.model.setSelected();
			}
		});
	},
	render: function() {
		this.defaultRender();
	},
	defaultRender: function() {
		var that;
		this.$el.css({
			left: this.model.get('left'),
			top: this.model.get('top'),
			width: this.model.sizeChangable ? this.model.get('width') : 'auto',
			height: this.model.sizeChangable ? this.model.get('height') : 'auto'
		});
		if (this.model.angleChangable) {
			this.$inner.css('transform', 'rotate(' + (this.model.get('angle' || 0)) + 'deg)');
		}
		if (this.model.selected) {
			this.$el.addClass('advp-is-selected');
			this.$el.attr('tabindex', 1);
			this.$el.focus();
			that = this;
			if (this.model.sizeChangable) {
				this.$el.resizable({
					handles: 'all',
					resize: function(event, ui) {
						that.modelSet({
							left: ui.position.left,
							top: ui.position.top,
							width: ui.size.width,
							height: ui.size.height
						});
					},
					stop: function(event, ui) {
						that.model.set({
							left: ui.position.left,
							top: ui.position.top,
							width: ui.size.width,
							height: ui.size.height
						});
						that.$el.focus();
					}
				});
			}
			if (this.model.angleChangable) {
				this.$inner.rotatable({
					angle: that.model.toRadians(),
					rotate: function(event, ui) {
						that.modelSet({
							angle: that.model.toDegrees(ui.angle.current)
						});
					},
					stop: function(event, ui) {
						that.model.set({
							angle: that.model.toDegrees(ui.angle.current)
						});
						that.$el.focus();
					}
				});
			}
		} else {
			this.$el.removeClass('advp-is-selected');
			this.$el.removeAttr('tabindex');
			if (this.$el.is('.ui-resizable')) {
				this.$el.resizable('destroy');
			}
			if (this.$inner.is('.ui-rotatable')) {
				this.$inner.rotatable('destroy');
			}
		}
	},
	selectOnClick: function() {
		this.model.setSelected();
	},
	removeOnDelete: function(event) {
		if (event.which === 46 && this.model.selected) {
			this.model.destroy();
		}
	}
});

AdvPopup = AdvPopup || {};

AdvPopup.OptionsView = AdvPopup.View.extend({
	tagName: 'div',
	className: 'advp-options',
	title: 'Options',
	optionsTemplate: _.template(''),
	template: _.template('<div class="panel"> <div class="panel-heading font-bold"><%= title %></div> <div class="panel-body"> <%= options %> </div> </div>'),
	defaultInitialize: function() {
		this.$el.appendTo(AdvPopup.app.$optionsWrapper);
	},
	render: function() {
		this.defaultRender();
	},
	defaultRender: function() {
		if (this.model.selected) {
			this.$el.show(0);
			this.$el.html(this.template({
				title: this.title,
				options: this.optionsTemplate(this.model.attributes)
			}));
		} else {
			this.$el.hide(10);
		}
	}
});

AdvPopup = AdvPopup || {};

AdvPopup.OrderingView = Backbone.View.extend({
	el: '.advp-ordering-wrapper',
	itemTemplate: _.template('<li id="<%- id %>" class="list-group-item advp-ordering-item<% if (selected) { %> advp-is-selected <% } %>" href="#"><%= caption %></li>'),
	events: {
		'click .advp-ordering-item': 'selectOnClick'
	},
	initialize: function() {
		var that;
		this.listenTo(this.model.overlay, 'change selected:change', this.render);
		this.listenTo(this.model.popup, 'change selected:change', this.render);
		this.listenTo(this.model.layers, 'reset', this.listenNewLayers);
		this.listenTo(this.model.layers, 'add', this.listenNewLayer);
		this.listenTo(this.model.layers, 'remove', this.stopListenLayer);
		this.listenTo(this.model.layers, 'change', this.render);
		this.$dynamicWrapper = jQuery('<ul class="list-group advp-ordering-dynamic-wrapper"></ul>').appendTo(this.$('.advp-dynamic-layers-wrapper'));
		this.$staticWrapper = jQuery('<ul class="list-group advp-ordering-static-wrapper"></ul>').appendTo(this.$('.advp-static-layers-wrapper'));
		that = this;
		this.$dynamicWrapper.sortable({
			stop: function(event, ui) {
				var index, length, model;
				if (model = that.getModelByElement(ui.item)) {
					length = that.model.layers.length;
					index = ui.item.index();
					if (length > 1) {
						that.model.layers.remove(model);
						that.model.layers.add(model, {
							at: length - index - 1
						});
						that.render();
					}
				}
			}
		});
		this.render();
	},
	listenNewLayers: function(layers) {
		var that;
		that = this;
		layers.each(function(layer) {
			that.listenTo(layer, 'selected:change', that.render);
		});
		this.render();
	},
	listenNewLayer: function(layer) {
		this.listenTo(layer, 'selected:change', this.render);
	},
	stopListenLayer: function(layer) {
		this.stopListening(layer, 'selected:change');
		this.render();
	},
	render: function() {
		var that;
		this.$staticWrapper.html('');
		this.$dynamicWrapper.html('');
		that = this;
		_.each([this.model.overlay, this.model.popup], function(model) {
			that.$staticWrapper.append(that.itemTemplate({
				id: 'advp-ordering-item-' + model.cid,
				caption: model.getCaption(),
				selected: model.selected
			}));
		});
		this.model.layers.each(function(layer) {
			that.$dynamicWrapper.prepend(that.itemTemplate({
				id: 'advp-ordering-item-' + layer.cid,
				caption: layer.getCaption(),
				selected: layer.selected
			}));
		});
	},
	getModelByElement: function(el) {
		var id, model;
		if (!(id = jQuery(el).attr('id'))) {
			return false;
		}
		if (!(id = id.split('-').pop())) {
			return false;
		}
		if (!(model = AdvPopup.app.findModelByCid(id))) {
			return false;
		}
		return model;
	},
	selectOnClick: function(event) {
		var model;
		if (model = this.getModelByElement(event.target)) {
			AdvPopup.app.setSelected(model);
		}
	}
});

AdvPopup = AdvPopup || {};

AdvPopup.OverlayOptionsView = AdvPopup.OptionsView.extend({
	title: 'Overlay Options',
	optionsTemplate: _.template('<div class="form-horizontal"> <div class="control-group"> <label for="" class="control-label">Backgrounds</label> <div class="controls"> <div class="input-append" style="margin-bottom: 10px;"> <input type="text" class="advp-option-bg-image" value="<%- image %>" /> <span class="input-group-btn"> <a class="btn btn-default btn-change-option-bg-image">Select Image</a> </span> </div> <div> <select class="advp-option-bg-repeat"> <option value=""<%- repeat ===\'\' ? \'selected="selected"\' : \'\' %>>Repeat</option> <option value="repeat-x"<%- repeat ===\'repeat-x\' ? \'selected="selected"\' : \'\' %>>Repeat Horizontally</option> <option value="repeat-y"<%- repeat ===\'\' ? \'selected="selected"\' : \'\' %>>Repeat Vertically</option> <option value="no-repeat"<%- repeat ===\'\' ? \'selected="selected"\' : \'\' %>>No Repeat</option> </select> <select class="advp-option-bg-position input-small"> <option value=""<%= repeat === \'\' ? \'selected="selected"\' : \'\' %>>left top</option> <option value="0% 50%"<%= repeat === \'0% 50%\' ? \'selected="selected"\' : \'\' %>>left center</option> <option value="0% 100%"<%= repeat === \'0% 100%\' ? \'selected="selected"\' : \'\' %>>left bottom</option> <option value="100% 0%"<%= repeat === \'100% 0%\' ? \'selected="selected"\' : \'\' %>>right top</option> <option value="100% 50%"<%= repeat === \'100% 50%\' ? \'selected="selected"\' : \'\' %>>right center</option> <option value="100% 100%"<%= repeat === \'100% 100%\' ? \'selected="selected"\' : \'\' %>>right bottom</option> <option value="50% 0%"<%= repeat === \'50% 0%\' ? \'selected="selected"\' : \'\' %>>center top</option> <option value="50% 50%"<%= repeat === \'50% 50%\' ? \'selected="selected"\' : \'\' %>>center center</option> <option value="50% 100%"<%= repeat === \'50% 100%\' ? \'selected="selected"\' : \'\' %>>center bottom</option> </select> <select class="advp-option-bg-attachment input-small"> <option value=""<%= repeat === \'\' ? \'selected="selected"\' : \'\' %>>scroll</option> <option value="fixed"<%= repeat === \'fixed\' ? \'selected="selected"\' : \'\' %>>fixed</option> </select> </div> </div> </div> <div class="control-group"> <label class="control-label">Color</label> <div class="controls"> <input type="text" class="advp-option-bg-color" value="<%- color %>" /> </div> </div> <div class="control-group"> <label class="control-label">Opacity</label> <div class="controls"> <input type="text" class="slider slider-horizontal advp-option-opacity" data-slider-value="<%- opacity * 100 %>" data-slider-min="10" data-slider-max="100" data-slider-step="5" data-slider-orientation="horizontal" value="<%- opacity * 100 %>" /> </div> </div> </div>'),
	events: {
		'change input': 'updateOptions',
		'change select': 'updateOptions',
		'click .btn-change-option-bg-image': 'selectImage'
	},
	render: function() {
		var that;
		this.defaultRender();
		that = this;
		jQuery.minicolors.defaults = jQuery.extend(jQuery.minicolors.defaults, {
			opacity: true,
			position: 'top left'
		});
		this.$('.advp-option-bg-color').minicolors({
			change: function(value, opacity) {
				that.modelSet({
					color: value += ', ' + opacity
				});
			}
		});
		this.$('.advp-option-bg-image').attr('id', 'advp-option-bg-image-' + this.model.cid);
		this.$('.advp-option-opacity').slider().on('slide slideStop', function() {
			that.updateOptions();
		});
	},
	updateOptions: function() {
		this.modelSet({
			image: this.$('.advp-option-bg-image').val(),
			repeat: this.$('.advp-option-bg-repeat').val(),
			position: this.$('.advp-option-bg-position').val(),
			attachment: this.$('.advp-option-bg-attachment').val(),
			color: this.$('.advp-option-bg-color').val(),
			opacity: parseInt(this.$('.advp-option-opacity').val()) / 100
		});
	},
	selectImage: function(event) {
		var fieldId, that;
		that = this;
		fieldId = jQuery(event.target).closest('.controls').find('input').attr('id');
		jQuery.fancybox.open({
			href: 'index.php?option=com_media&view=images&tmpl=component&fieldid=' + fieldId,
			width: 800,
			height: 500,
			overlay: true,
			type: 'iframe',
			afterClose: function() {
				that.updateOptions();
			}
		});
	}
});

AdvPopup = AdvPopup || {};

AdvPopup.OverlayView = AdvPopup.View.extend({
	el: '.advp-overlay-wrapper',
	events: {
		'click': 'selectOnClick'
	},
	render: function() {
		if (this.model.get('image')) {
			this.$el.css('background-image', 'url(' + AdvPopup.Common.getAbsUrl(this.model.get('image') + ')'));
		} else {
			this.$el.css('background-image', '');
		}
		this.$el.css('background-repeat', this.model.get('repeat'));
		this.$el.css('background-position', this.model.get('position'));
		this.$el.css('background-attachment', this.model.get('attachment'));
		this.$el.css('background-color', this.model.get('color'));
		this.$el.css('opacity', this.model.get('opacity'));
		this.$el.toggleClass('advp-is-selected', this.model.selected);
	}
});

AdvPopup = AdvPopup || {};

AdvPopup.PopupOptionsView = AdvPopup.OptionsView.extend({
	title: 'Popup Options',
	optionsTemplate: _.template('<div class="form-horizontal"> <div class="control-group"> <label class="control-label">Color</label> <div class="controls"> <input type="text" class="advp-option-bg-color" value="<%- color %>" /> </div> </div> <div class="control-group"> <label class="control-label">Width</label> <div class="controls"> <input type="text" class="advp-option-width" value="<%- width %>" /> </div> </div> <div class="control-group"> <label class="control-label">Height</label> <div class="controls"> <input type="text" class="advp-option-height" value="<%- height %>" /> </div> </div> <div class="control-group"> <label class="control-label">Audio</label> <div class="controls"> <div class="input-append"> <input type="text" class="advp-option-audio" value="<%- audio %>" /> <span class="input-group-btn"> <a href="#" class="btn btn-change-option-audio">Select Audio</a> </span> </div> </div> </div> </div>'),
	events: {
		'change input': 'updateOptions',
		'click .btn-change-option-audio': 'selectAudio'
	},
	render: function() {
		var that;
		this.defaultRender();
		that = this;
		jQuery.minicolors.defaults = jQuery.extend(jQuery.minicolors.defaults, {
			opacity: true,
			position: 'top left'
		});
		this.$('.advp-option-bg-color').attr({
			'data-format': 'hex'
		});
		this.$('.advp-option-bg-color').minicolors({
			change: function(value, opacity) {
				that.modelSet({
					color: value += ', ' + opacity
				});
			}
		});
	},
	updateOptions: function() {
		this.modelSet({
			color: this.$('.advp-option-bg-color').val(),
			width: parseInt(this.$('.advp-option-width').val() || 500),
			height: parseInt(this.$('.advp-option-height').val() || 400),
			audio: this.$('.advp-option-audio').val()
		});
	},
	selectAudio: function() {
		var audio;
		if (audio = prompt('Please select an audio file!')) {
			this.$('.advp-option-audio').val(audio).change();
		}
	}
});

AdvPopup = AdvPopup || {};

AdvPopup.PopupView = AdvPopup.View.extend({
	el: '.advp-popup-wrapper',
	events: {
		'click': 'selectOnClick'
	},
	render: function() {
		var that;
		this.$el.css('background-color', this.model.get('color'));
		this.$el.css('width', this.model.get('width'));
		this.$el.css('height', this.model.get('height'));
		this.$el.toggleClass('advp-is-selected', this.model.selected);
		that = this;
		if (this.model.selected) {
			this.$el.resizable({
				handles: 'e, s, se',
				resize: function(event, ui) {
					that.modelSet({
						width: ui.size.width,
						height: ui.size.height
					});
				},
				stop: function(event, ui) {
					that.modelSet({
						width: ui.size.width,
						height: ui.size.height
					});
					that.$el.focus();
				}
			});
		} else {
			if (this.$el.is('.ui-resizable')) {
				this.$el.resizable('destroy');
			}
		}
	}
});
