var AdvPopup;

AdvPopup = AdvPopup || {};

AdvPopup.Layers = Backbone.Collection.extend({
	model: function(attrs, options) {
		var LayerClass;
		LayerClass = AdvPopup.app.getRegisteredLayerClassByType(attrs['type']);
		if (!LayerClass) {
			console.error('Cannot detect layer type', attrs, options);
			return new AdvPopup.Layer(attrs, options);
		}
		return new LayerClass(attrs, options);
	}
});

AdvPopup = AdvPopup || {};

AdvPopup.Common = {
	siteUrl: '',
	getAbsUrl: function(url) {
		var regex;
		regex = /(http|https):\/\/(\w+:{0,1}\w*)?(\S+)(:[0-9]+)?(\/|\/([\w#!:.?+=&%!\-\/]))?/;
		if (regex.test(url)) {
			return url;
		} else {
			return AdvPopup.Common.siteUrl + url;
		}
	}
};

AdvPopup = AdvPopup || {};

AdvPopup.Layer = Backbone.Model.extend({
	defaults: {
		type: '',
		left: 20,
		top: 20,
		width: 50,
		height: 50,
		angle: 0
	},
	sizeChangable: true,
	angleChangable: true
});

AdvPopup = AdvPopup || {};

AdvPopup.Overlay = Backbone.Model.extend({
	defaults: {
		image: '',
		repeat: '',
		position: '',
		attachment: '',
		color: '#000',
		opacity: '0.7'
	},
	initialize: function() {
		this.view = new AdvPopup.OverlayView({
			model: this
		});
	}
});

AdvPopup = AdvPopup || {};

AdvPopup.Popup = Backbone.Model.extend({
	defaults: {
		color: '#e5e5e5',
		width: 500,
		height: 400,
		audio: ''
	},
	initialize: function() {
		this.view = new AdvPopup.PopupView({
			model: this
		});
	}
});

AdvPopup = AdvPopup || {};

AdvPopup.AppView = Backbone.View.extend({
	el: 'body',
	isBackend: false,
	events: {
		'click .advp-overlay-wrapper': 'closeOnClickOverlay'
	},
	registeredLayersClasses: {},
	getLayerClassType: function(LayerClass) {
		if (typeof LayerClass.prototype.defaults === 'function') {
			return LayerClass.prototype.defaults().type;
		} else {
			return LayerClass.prototype.defaults.type;
		}
	},
	getRegisteredLayerClassByType: function(type) {
		return this.registeredLayersClasses[type];
	},
	registerLayerClass: function(LayerClass) {
		var type;
		if (!(LayerClass.prototype instanceof AdvPopup.Layer)) {
			console.error('Tried to register layer class that does not extend AdvPopup.Layer', LayerClass);
			return false;
		}
		type = this.getLayerClassType(LayerClass);
		if (typeof type !== 'string') {
			console.error('Invalid layer type: ' + type, LayerClass);
			return false;
		}
		if (typeof this.registeredLayersClasses[type] !== 'undefined') {
			console.error('Layer type "' + type + '" already registered', LayerClass);
			return false;
		}
		this.registeredLayersClasses[type] = LayerClass;
		return true;
	},
	initialize: function(data) {
		var app, that;
		app = AdvPopup.app = this;
		this.$wrapper = jQuery('<div class="advp-wrapper"><div class="advp-overlay-wrapper"></div><div class="advp-popup-wrapper"></div></div>').appendTo(this.$el);
		this.$overlayWrapper = this.$('.advp-overlay-wrapper');
		this.$popupWrapper = this.$('.advp-popup-wrapper');
		this.overlay = new AdvPopup.Overlay;
		this.popup = new AdvPopup.Popup;
		this.layers = new AdvPopup.Layers;
		Backbone.Events.trigger('layer:register', this);
		data = this.escapeSpecialChars(data);
		data = JSON.parse(data || '{}');
		if (data.overlay) {
			this.overlay.set(data.overlay);
		}
		if (data.popup) {
			this.popup.set(data.popup);
		}
		if (data.layers) {
			this.layers.reset(data.layers);
		}
		this.render();
		that = this;
		jQuery(window).resize(function() {
			that.responsivePopup();
		});
	},
	render: function() {
		var that;
		that = this;
		this.overlay.view.render();
		this.popup.view.render();
		this.layers.each(function(layer) {
			layer.view.render();
			return that.$popupWrapper.append(layer.view.$el);
		});
		this.$popupWrapper.attr('data-width', parseInt(this.$popupWrapper.css('width')));
		this.$popupWrapper.attr('data-height', parseInt(this.$popupWrapper.css('height')));
		this.layers.each(function(layer) {
			that.updateAttr(layer.view.$el);
			layer.view.$el.find('*').each(function() {
				that.updateAttr(this);
			});
		});
		this.responsivePopup();
		return this;
	},
	closeOnClickOverlay: function(event) {
		if (jQuery(event.target).is(this.$overlayWrapper)) {
			this.closePopup();
		}
	},
	closePopup: function() {
		this.$wrapper.remove();
	},
	toggleMusic: function() {
		var player;
		if (this.$('#popup-audio-player').length) {
			player = this.$('#popup-audio-player').get(0);
			if (player.paused) {
				player.play();
			} else {
				player.pause();
			}
		}
	},
	responsivePopup: function() {
		var height, newh, neww, scale, viewport, width, winh, winw;
		winw = jQuery(window).width();
		winh = jQuery(window).height();
		viewport = {
			width: Math.max(320, winw),
			height: Math.max(320, winh)
		};
		width = parseInt(this.$popupWrapper.attr('data-width'), 10);
		height = parseInt(this.$popupWrapper.attr('data-height'), 10);
		scale = Math.min((viewport.width - 20) / width, viewport.height / height);
		if (scale > 1) {
			scale = 1;
		}
		neww = parseInt(width * scale, 10);
		newh = parseInt(height * scale, 10);
		this.$popupWrapper.css({
			'width': neww + 'px',
			'height': newh + 'px'
		});
		this.layers.each(function(layer) {
			var layerfs, layerh, layerl, layert, layerw, tlayer;
			tlayer = layer.view.$el;
			layerl = jQuery(tlayer).attr('data-left');
			layert = jQuery(tlayer).attr('data-top');
			layerw = jQuery(tlayer).attr('data-width');
			layerh = jQuery(tlayer).attr('data-height');
			layerfs = jQuery(tlayer).attr('data-font-size');
			if (layerw) {
				jQuery(tlayer).css('width', parseInt(layerw * scale, 10) + 'px');
			}
			if (layerh) {
				jQuery(tlayer).css('height', parseInt(layerh * scale, 10) + 'px');
			}
			if (layerfs) {
				jQuery(tlayer).css('font-size', Math.max(4, parseInt(layerfs * scale, 10)) + 'px');
			}
			jQuery(tlayer).css({
				'left': parseInt(layerl * scale, 10) + 'px',
				'top': parseInt(layert * scale, 10) + 'px'
			});
			return jQuery(tlayer).find('*').each(function() {
				var childfs, childh, childml, childmt, childw;
				childw = jQuery(this).attr('data-width');
				childh = jQuery(this).attr('data-height');
				childmt = jQuery(this).attr('data-margin-top');
				childml = jQuery(this).attr('data-margin-left');
				childfs = jQuery(this).attr('data-font-size');
				if (childw) {
					jQuery(this).css('width', parseInt(childw * scale, 10) + 'px');
				}
				if (childh) {
					jQuery(this).css('height', parseInt(childh * scale, 10) + 'px');
				}
				if (childmt) {
					jQuery(this).css('margin-top', parseInt(childmt * scale, 10) + 'px');
				}
				if (childml) {
					jQuery(this).css('margin-left', parseInt(childml * scale, 10) + 'px');
				}
				if (childfs) {
					jQuery(this).css('font-size', Math.max(4, parseInt(childfs * scale, 10)) + 'px');
				}
			});
		});
	},
	updateAttr: function(elem) {
		if (jQuery(elem).css('left') && jQuery(elem).css('left') !== 'auto') {
			jQuery(elem).attr('data-left', parseInt(jQuery(elem).css('left')));
		}
		if (jQuery(elem).css('top') && jQuery(elem).css('top') !== 'auto') {
			jQuery(elem).attr('data-top', parseInt(jQuery(elem).css('top')));
		}
		if (jQuery(elem).css('width') && jQuery(elem).css('width') !== 'auto') {
			jQuery(elem).attr('data-width', parseInt(jQuery(elem).css('width')));
		}
		if (jQuery(elem).css('height') && jQuery(elem).css('height') !== 'auto') {
			jQuery(elem).attr('data-height', parseInt(jQuery(elem).css('height')));
		}
		if (jQuery(elem).css('font-size') && jQuery(elem).css('font-size') !== 'auto') {
			jQuery(elem).attr('data-font-size', parseInt(jQuery(elem).css('font-size')));
		}
	},
	escapeSpecialChars: function(jsonString) {
		return jsonString.replace(/\n/g, "\\n").replace(/\\'/g, "\\'").replace(/\\"/g, '\\"').replace(/\\&/g, "\\&").replace(/\\r/g, "\\r").replace(/\\t/g, "\\t").replace(/\\b/g, "\\b").replace(/\\f/g, "\\f");
	}
});

AdvPopup = AdvPopup || {};

AdvPopup.LayerView = Backbone.View.extend({
	tagName: 'div',
	className: 'advp-layer',
	$inner: null,
	defaultInitialize: function() {
		return this.$inner = jQuery('<div class="advp-layer-inner"></div>').appendTo(this.$el);
	},
	defaultRender: function() {
		this.$el.css({
			left: this.model.get('left'),
			top: this.model.get('top'),
			width: this.model.sizeChangable ? this.model.get('width') : 'auto',
			height: this.model.sizeChangable ? this.model.get('height') : 'auto'
		});
		if (this.model.angleChangable) {
			return this.$inner.css('transform', 'rotate(' + (this.model.get('angle' || 0)) + 'deg)');
		}
	}
});

AdvPopup = AdvPopup || {};

AdvPopup.OverlayView = Backbone.View.extend({
	el: '.advp-overlay-wrapper',
	render: function() {
		this.$el.css('background-image', 'url(' + this.model.get('image') + ')');
		this.$el.css('background-repeat', this.model.get('repeat'));
		this.$el.css('background-position', this.model.get('position'));
		this.$el.css('background-attachment', this.model.get('attachment'));
		this.$el.css('background-color', this.model.get('color'));
		this.$el.css('opacity', this.model.get('opacity'));
	}
});

AdvPopup = AdvPopup || {};

AdvPopup.PopupView = Backbone.View.extend({
	el: '.advp-popup-wrapper',
	render: function() {
		var audio, url;
		this.$el.css('background-color', this.model.get('color'));
		this.$el.css('width', this.model.get('width'));
		this.$el.css('height', this.model.get('height'));
		if (audio = this.model.get('audio')) {
			url = AdvPopup.Common.getAbsUrl(audio);
			this.$audio = "<!-- autoplay -->";
			this.$audio += "<audio id='popup-audio-player' controls loop preload style='width: 1px; height: 1px; position: absolute; top: -9999px; left: -9999px;' >";
			this.$audio += "<source src='" + url + "' type='audio/mpeg; codecs=\"mp3\"'>";
			this.$audio += "<source src='" + url + "' type='audio/ogg; codecs=\"vorbis\"'>";
			this.$audio += "</audio>";
			this.$el.append(this.$audio);
			this.$('#popup-audio-player')[0].play();
			return;
		}
	}
});
