Backbone.Events.on('layer:register', function(app) {
	var Layer, LayerOptionsView, LayerView;
	if (app.isBackend) {
		LayerView = AdvPopup.LayerView.extend({
			initialize: function() {
				this.defaultInitialize();
				this.$spider = jQuery('<div class="advp-spider"><span class="advp-spider-web"></span><span class="advp-the-spider"></span></div>').appendTo(this.$inner);
				this.render();
			},
			render: function() {
				var that;
				this.defaultRender();
				this.$el.css({
					width: 50
				});
				this.$('.advp-spider-web').css({
					borderColor: this.model.get('web_color')
				});
				that = this;
				if (this.model.selected) {
					if (this.$el.is('.ui-resizable')) {
						this.$el.resizable('destroy');
					}
					this.$el.resizable({
						handles: 'n, s',
						resize: function(event, ui) {
							that.modelSet({
								left: ui.position.left,
								top: ui.position.top,
								height: ui.size.height
							});
						},
						stop: function(event, ui) {
							that.model.set({
								left: ui.position.left,
								top: ui.position.top,
								height: ui.size.height
							});
							that.$el.focus();
						}
					});
				}
			}
		});
		LayerOptionsView = AdvPopup.OptionsView.extend({
			title: 'Spider Options',
			optionsTemplate: _.template('<div  class="form-horizontal"> <div class="control-group"> <label class="control-label">Left</label> <div class="controls"> <input type="text" class="advp-option-left" value="<%- left %>" /> </div> </div> <div class="control-group"> <label class="control-label">Top</label> <div class="controls"> <input type="text" class="advp-option-top" value="<%- top %>" /> </div> </div> <div class="control-group"> <label class="control-label">Height</label> <div class="controls"> <input type="text" class="advp-option-height" value="<%- height %>" /> </div> </div> <div class="control-group"> <label class="control-label">Web Color</label> <div class="controls"> <input type="text" class="advp-option-web-color" value="<%- web_color %>" /> </div> </div> <div class="control-group"> <label class="control-label">Start Delay</label> <div class="controls"> <input type="text" class="advp-option-delay" value="<%- delay %>" /> </div> </div> <div class="control-group"> <label class="control-label">Min Speed</label> <div class="controls"> <input type="text" class="advp-option-min-speed" value="<%- min_speed %>" /> </div> </div> <div class="control-group"> <label class="control-label">Max Speed</label> <div class="controls"> <input type="text" class="advp-option-max-speed" value="<%- max_speed %>" /> </div> </div> </div>'),
			events: {
				'change input': 'updateOptions'
			},
			render: function() {
				var that;
				this.defaultRender();
				that = this;
				return this.$('.advp-option-web-color').minicolors({
					change: function(value) {
						that.modelSet({
							web_color: value
						});
					}
				});
			},
			updateOptions: function() {
				this.modelSet({
					left: parseInt(this.$('.advp-option-left').val()) || 20,
					top: parseInt(this.$('.advp-option-top').val()) || 20,
					height: parseInt(this.$('.advp-option-height').val()) || 50,
					delay: parseInt(this.$('.advp-option-delay').val()) || 200,
					min_speed: parseInt(this.$('.advp-option-min-speed').val()) || 1800,
					max_speed: parseInt(this.$('.advp-option-max-speed').val()) || 1800,
					web_color: this.$('.advp-option-web-color').val()
				});
			}
		});
	} else {
		LayerView = AdvPopup.LayerView.extend({
			initialize: function() {
				this.defaultInitialize();
				this.$spider = jQuery('<div class="advp-spider"><span class="advp-spider-web"></span><span class="advp-the-spider"></span></div>').appendTo(this.$inner);
				this.render();
			},
			render: function() {
				this.defaultRender();
				this.$theSpider = this.$spider.find('.advp-the-spider');
				this.$el.css({
					width: 50
				});
				this.$('.advp-spider-web').css({
					borderColor: this.model.get('web_color')
				});
				this.spiderMovement();
				this.slideTheSpider();
			},
			spiderMovement: function() {
				var that;
				that = this;
				setTimeout(function() {
					that.model.slideDirection = 'down';
					return that.slideTheSpider();
				}, this.model.get('start_delay'));
			},
			slideTheSpider: function() {
				var curr_height, curr_spider_position, height_factor, new_height, that;
				that = this;
				curr_height = this.$spider.height();
				curr_spider_position = this.$theSpider.attr('class').split(' ');
				curr_spider_position = curr_spider_position[1];
				height_factor = Math.ceil(this.model.get('height') / 10);
				if (this.model.slideDirection === 'down') {
					new_height = curr_height + height_factor;
					if (curr_spider_position === 'down-look-right' || curr_spider_position === '') {
						this.$theSpider.attr('class', 'advp-the-spider down-look-left');
					} else {
						this.$theSpider.attr('class', 'advp-the-spider down-look-right');
					}
				} else {
					new_height = curr_height - height_factor;
					if (curr_spider_position === 'up-look-right' || curr_spider_position === '') {
						this.$theSpider.attr('class', 'advp-the-spider up-look-left');
					} else {
						this.$theSpider.attr('class', 'advp-the-spider up-look-right');
					}
				}
				this.$spider.animate({
					height: new_height
				}, this.getRandomInt(this.model.get('min_speed'), this.model.get('max_speed')), function() {
					if (curr_height >= parseInt(that.model.get('height'), 10)) {
						that.model.slideDirection = 'up';
					}
					if (curr_height <= height_factor) {
						that.model.slideDirection = 'down';
					}
					that.slideTheSpider();
				});
			},
			getRandomInt: function(min, max) {
				var random;
				random = Math.floor(Math.random() * (max - min + 1)) + min;
				console.log(min, max);
				return random;
			}
		});
	}
	Layer = AdvPopup.Layer.extend({
		defaults: _.extend({}, AdvPopup.Layer.prototype.defaults, {
			type: 'spider',
			web_color: 'rgba(255, 255, 255, 0.7)',
			delay: 200,
			min_speed: 1800,
			max_speed: 1800
		}),
		angleChangable: false,
		initialize: function(attrs, options) {
			if (attrs) {
				this.isNewLayer = false;
			}
			if (app.isBackend) {
				this.view = new LayerView({
					id: 'layer-' + this.cid,
					model: this
				});
				this.optionsView = new LayerOptionsView({
					id: 'layer-options-' + this.cid,
					model: this
				});
				this.defaultInitialize();
			} else {
				this.view = new LayerView({
					id: 'layer-' + this.cid,
					model: this
				});
			}
		},
		getCaption: function() {
			var caption;
			if (!(caption = this.get('alt'))) {
				caption = 'Layer Spider ' + this.cid;
			}
			return '<i class="fa fa-bug"></i> ' + caption;
		}
	});
	app.registerLayerClass(Layer);
});
